@@ -476,12 +476,10 @@ def get_quick_stats(ticker_list, threads=True, minprice=0, maxprice=99999999):
 
     return stats_df
 
-def print_df(df, filename, writecsv, api):
+def print_df(df, filename, writecsv):
 
     # turn index (symbols) into regular column for printing purposes
     df.reset_index(inplace=True)
-    if api:
-        return df
     now = datetime.now()
     # dd/mm/YY H:M:S
     dt_string = now.strftime("%d/%m/%Y %H:%M:%S")
@@ -502,87 +500,37 @@ def print_df(df, filename, writecsv, api):
             file.write(tabulate(df, headers='keys', floatfmt='.3f', showindex=False))
             file.write('\n\n')
 
-    print("Wrote to file successfully: ")
     print(completeName)
 
-def acquire(imported=False):
-    import argparse
+def acquire(jsonify=False):
     import json
     import pandas as pd
     from collections import Counter
-    # Instantiate the parser
-    parser = argparse.ArgumentParser(description='AutoDD Optional Parameters')
-
-    parser.add_argument('--interval', nargs='?', const=24, type=int, default=24,
-                    help='Choose a time interval in hours to filter the results, default is 24 hours')
-
-    parser.add_argument('--sub', nargs='?', const='pennystocks', type=str, default='pennystocks',
-                    help='Choose a different subreddit to search for tickers in, default is pennystocks')
-
-    parser.add_argument('--min', nargs='?', const=10, type=int, default=10,
-                    help='Filter out results that have less than the min score, default is 10')
-
-    parser.add_argument('--minprice', nargs='?', const=0, type=int, default=0,
-                    help='Filter out results less than the min price set, default is 0')
-
-    parser.add_argument('--maxprice', nargs='?', const=9999999, type=int, default=9999999,
-                    help='Filter out results more than the max price set, default is 9999999')
-
-    parser.add_argument('--advanced', default=False, action='store_true',
-                    help='Using this parameter shows advanced yahoo finance information on the ticker')
-
-    parser.add_argument('--sort', nargs='?', const=1, type=int, default=1,
-                    help='Sort the results table by descending order of score, 1 = sort by total score, 2 = sort by recent score, 3 = sort by previous score, 4 = sort by change in score, 5 = sort by # of rocket emojis')
-
-    parser.add_argument('--allsub', default=True, action='store_true',
-                    help='Using this parameter searchs from all subreddits.')
-
-    parser.add_argument('--psaw', default=False, action='store_true',
-                    help='Using this parameter selects psaw (push-shift) as the reddit scraper over praw (reddit-api)')
-
-    parser.add_argument('--no-threads', action='store_false', dest='threads',
-                    help='Disable multi-tasking (enabled by default). Multi-tasking speeds up downloading of data.')
-
-    parser.add_argument('--csv', default=False, action='store_true',
-                    help='Using this parameter produces a table_records.csv file, rather than a .txt file')
-
-    parser.add_argument('--filename', nargs='?', const='table_records', type=str, default='table_records',
-                    help='Change the file name from table_records to whatever you wish')
-                    
-
-    args = parser.parse_args()
-    if imported:
-        # call reddit api to get results
-        current_scores, current_rocket_scores, prev_scores, prev_rocket_scores = get_submission_generators(args.interval, args.sub, args.allsub, args.psaw)  
-        results_df = populate_df(current_scores, prev_scores, args.interval)
-        results_df = filter_df(results_df, args.min)
-        rockets = Counter(current_rocket_scores) + Counter(prev_rocket_scores)
-        results_df.insert(loc=4, column='Rockets', value=pd.Series(rockets))
-        results_df = results_df.fillna(value=0).astype({'Rockets': 'int32'})
-        results_df = get_financial_stats(results_df, args.threads, args.advanced, args.minprice, args.maxprice)
-        # Sort by Total (sort = 1), Recent (sort = 2), Prev (sort = 3), Change (sort = 4), Rockets (sort = 5)
-        results_df.sort_values(by=results_df.columns[args.sort - 1], inplace=True, ascending=False)
-        json_v = json.dumps(results_df.to_dict())
-        return json_v
-
-    print("Getting submissions...")
+    interval = 24
+    sub = 'pennystocks'
+    min = 10
+    minprice = 0
+    maxprice = 9999999
+    advanced = True
+    sort = 1
+    allsub = True
+    psaw = False
+    threads = False
+    csv = True
+    filename = 'Digits_Reddit_Export'
+    
     # call reddit api to get results
-    current_scores, current_rocket_scores, prev_scores, prev_rocket_scores = get_submission_generators(args.interval, args.sub, args.allsub, args.psaw)  
-
-    print("Populating results...")
-    results_df = populate_df(current_scores, prev_scores, args.interval)
-    results_df = filter_df(results_df, args.min)
-
-    print("Counting rockets...")
+    current_scores, current_rocket_scores, prev_scores, prev_rocket_scores = get_submission_generators(interval, sub, allsub, psaw)  
+    results_df = populate_df(current_scores, prev_scores, interval)
+    results_df = filter_df(results_df, min)
     rockets = Counter(current_rocket_scores) + Counter(prev_rocket_scores)
     results_df.insert(loc=4, column='Rockets', value=pd.Series(rockets))
     results_df = results_df.fillna(value=0).astype({'Rockets': 'int32'})
-
-    print("Getting financial stats...")
-    results_df = get_financial_stats(results_df, args.threads, args.advanced, args.minprice, args.maxprice)
-
+    results_df = get_financial_stats(results_df, threads, advanced, minprice, maxprice)
     # Sort by Total (sort = 1), Recent (sort = 2), Prev (sort = 3), Change (sort = 4), Rockets (sort = 5)
-    results_df.sort_values(by=results_df.columns[args.sort - 1], inplace=True, ascending=False)
-
-    print_df(results_df, args.filename, args.csv)
-
+    results_df.sort_values(by=results_df.columns[sort - 1], inplace=True, ascending=False)
+    if jsonify:
+        # json_v = json.dumps(results_df.to_dict())
+        return results_df.to_dict()
+    else:
+        print_df(results_df, filename, csv)
